# Package for IxLoad Automation
[![Python 2.7](https://img.shields.io/badge/Python-2.7-blue.svg)](#)
[![Python 3](https://img.shields.io/badge/Python-3-blue.svg)](#)

## To Install:
pip install ixload

## To import into project
from ixload import IxLoadUtils as IxLoadUtils \
from ixload import IxLoadTestSettings as TestSettings \
from ixload import IxRestUtils as IxRestUtils \
from ixload import IxRestPyUtils as IxRestPyUtils

##Information on IxLoad Modules visit github.com/OpenIxia
[OpenIxia](https://github.com/OpenIxia/IxLoad)

